@@ -27,26 +27,23 @@
 #include "gcm-calibrate.h"
 #include "gcm-calibrate-dialog.h"
 #include "gcm-calibrate-manual.h"
+#include "gcm-calibrate-native.h"
 #include "gcm-cie-widget.h"
 #include "gcm-client.h"
-#include "gcm-clut.h"
+#include "gcm-debug.h"
 #include "gcm-device.h"
 #include "gcm-device-udev.h"
 #include "gcm-device-xrandr.h"
-#include "gcm-dmi.h"
-#include "gcm-edid.h"
 #include "gcm-exif.h"
 #include "gcm-gamma-widget.h"
-#include "gcm-image.h"
 #include "gcm-print.h"
 #include "gcm-profile.h"
 #include "gcm-profile-store.h"
-#include "gcm-tables.h"
 #include "gcm-trc-widget.h"
 #include "gcm-utils.h"
-#include "gcm-xyz.h"
+#include "gcm-color.h"
 #include "gcm-profile.h"
-#include "gcm-xyz.h"
+#include "gcm-color.h"
 
 /** ver:1.0 ***********************************************************/
 static GMainLoop *_test_loop = NULL;
@@ -127,45 +124,14 @@ gcm_test_assert_basename (const gchar *filename1, const gchar *filename2)
 	g_free (basename2);
 }
 
-static void
-gcm_test_brightness_func (void)
-{
-	GcmBrightness *brightness;
-	gboolean ret;
-	GError *error = NULL;
-	guint orig_percentage;
-	guint percentage;
-
-	brightness = gcm_brightness_new ();
-	g_assert (brightness != NULL);
-
-	ret = gcm_brightness_get_percentage (brightness, &orig_percentage, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-
-	ret = gcm_brightness_set_percentage (brightness, 10, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-
-	ret = gcm_brightness_get_percentage (brightness, &percentage, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-	g_assert_cmpint (percentage, >, 5);
-	g_assert_cmpint (percentage, <, 15);
-
-	ret = gcm_brightness_set_percentage (brightness, orig_percentage, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-
-	g_object_unref (brightness);
-}
-
 static void
 gcm_test_calibrate_func (void)
 {
 	GcmCalibrate *calibrate;
 	gboolean ret;
 	GError *error = NULL;
+	gchar *model;
+	gchar *manufacturer;
 
 	calibrate = gcm_calibrate_new ();
 	g_assert (calibrate != NULL);
@@ -174,9 +140,12 @@ gcm_test_calibrate_func (void)
 	ret = gcm_calibrate_set_from_exif (GCM_CALIBRATE(calibrate), TESTDATADIR "/test.tif", &error);
 	g_assert_no_error (error);
 	g_assert (ret);
-	g_assert_cmpstr (gcm_calibrate_get_model_fallback (calibrate), ==, "NIKON D60");
-	g_assert_cmpstr (gcm_calibrate_get_manufacturer_fallback (calibrate), ==, "NIKON CORPORATION");
-
+	model = gcm_calibrate_get_profile_model (calibrate);
+	manufacturer = gcm_calibrate_get_profile_manufacturer (calibrate);
+	g_assert_cmpstr (model, ==, "NIKON D60");
+	g_assert_cmpstr (manufacturer, ==, "NIKON CORPORATION");
+	g_free (model);
+	g_free (manufacturer);
 	g_object_unref (calibrate);
 }
 
@@ -189,10 +158,90 @@ gcm_test_calibrate_dialog_func (void)
 	g_object_unref (calibrate_dialog);
 }
 
+static void
+gcm_test_calibrate_native_func (void)
+{
+	gboolean ret;
+	GError *error = NULL;
+	GcmCalibrate *calibrate;
+	GcmClient *client;
+	GcmX11Screen *screen;
+	GcmDevice *device;
+	gchar *contents;
+	gchar *filename;
+
+	calibrate = gcm_calibrate_native_new ();
+	g_assert (calibrate != NULL);
+
+	g_object_set (calibrate,
+		      "output-name", "LVDS1",
+		      NULL);
+
+	/* create a virtual device we can "calibrate" */
+	client = gcm_client_new ();
+	g_assert (client != NULL);
+	g_setenv ("GCM_TEST", "1", TRUE);
+	filename = gcm_utils_get_default_config_location ();
+	contents = g_strdup_printf ("[xrandr_hewlett_packard_hp_lp2480zx_3cm82200kv]\n"
+				    "serial=3CM82200KV\n"
+				    "model=HP LP2480zx\n"
+				    "manufacturer=Hewlett Packard\n"
+				    "title=Hewlett Packard - HP LP2480zx - 24\"\n"
+				    "type=display\n"
+				    "colorspace=rgb");
+	ret = g_file_set_contents (filename, contents, -1, &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+
+	ret = gcm_client_coldplug (client, GCM_CLIENT_COLDPLUG_SAVED, &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+
+	device = gcm_client_get_device_by_id (client, "xrandr_hewlett_packard_hp_lp2480zx_3cm82200kv");
+	g_assert (device != NULL);
+
+	/* set device */
+	g_object_set (device,
+		      "native-device", "LVDS1",
+		      NULL);
+	ret = gcm_calibrate_set_from_device (calibrate, device, &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+
+	/* use a screen */
+	screen = gcm_x11_screen_new ();
+	ret = gcm_x11_screen_assign (screen, NULL, &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+
+	/* clear any VCGT */
+	ret = gcm_device_xrandr_reset (GCM_DEVICE_XRANDR (device), &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+
+	/* do the calibration */
+	ret = gcm_calibrate_display (calibrate, NULL, &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+
+	/* be good and restore the settings if they changed */
+	ret = g_spawn_command_line_sync (BINDIR "/gcm-apply", NULL, NULL, NULL, &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+
+	g_object_unref (client);
+	g_object_unref (device);
+	g_unlink (filename);
+	g_free (contents);
+	g_free (filename);
+	g_object_unref (screen);
+	g_object_unref (calibrate);
+}
+
 static void
 gcm_test_calibrate_manual_func (void)
 {
-	GcmCalibrateManual *calibrate;
+	GcmCalibrate *calibrate;
 	gboolean ret;
 	GError *error = NULL;
 
@@ -205,7 +254,7 @@ gcm_test_calibrate_manual_func (void)
 		      NULL);
 
 	/* calibrate display manually */
-	ret = gcm_calibrate_display (GCM_CALIBRATE(calibrate), NULL, &error);
+	ret = gcm_calibrate_display (calibrate, NULL, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
 
@@ -220,12 +269,16 @@ gcm_test_cie_widget_func (void)
 	GtkWidget *dialog;
 	GtkWidget *vbox;
 	GcmProfile *profile;
-	GcmXyz *white;
-	GcmXyz *red;
-	GcmXyz *green;
-	GcmXyz *blue;
+	GcmColorXYZ *white;
+	GcmColorXYZ *red;
+	GcmColorXYZ *green;
+	GcmColorXYZ *blue;
 	gint response;
 	GFile *file = NULL;
+	GcmColorYxy white_Yxy;
+	GcmColorYxy red_Yxy;
+	GcmColorYxy green_Yxy;
+	GcmColorYxy blue_Yxy;
 
 	widget = gcm_cie_widget_new ();
 	g_assert (widget != NULL);
@@ -241,11 +294,16 @@ gcm_test_cie_widget_func (void)
 		      NULL);
 	g_object_unref (file);
 
+	gcm_color_convert_XYZ_to_Yxy (white, &white_Yxy);
+	gcm_color_convert_XYZ_to_Yxy (red, &red_Yxy);
+	gcm_color_convert_XYZ_to_Yxy (green, &green_Yxy);
+	gcm_color_convert_XYZ_to_Yxy (blue, &blue_Yxy);
+
 	g_object_set (widget,
-		      "red", red,
-		      "green", green,
-		      "blue", blue,
-		      "white", white,
+		      "red", &red_Yxy,
+		      "green", &green_Yxy,
+		      "blue", &blue_Yxy,
+		      "white", &white_Yxy,
 		      NULL);
 
 	/* show in a dialog as an example */
@@ -266,98 +324,10 @@ gcm_test_cie_widget_func (void)
 	gtk_widget_destroy (dialog);
 
 	g_object_unref (profile);
-	g_object_unref (white);
-	g_object_unref (red);
-	g_object_unref (green);
-	g_object_unref (blue);
-}
-
-static void
-gcm_test_clut_func (void)
-{
-	GcmClut *clut;
-	GPtrArray *array;
-	const GcmClutData *data;
-
-	clut = gcm_clut_new ();
-	g_assert (clut != NULL);
-
-	/* set some initial properties */
-	g_object_set (clut,
-		      "size", 3,
-		      "contrast", 100.0f,
-		      "brightness", 0.0f,
-		      NULL);
-
-	array = gcm_clut_get_array (clut);
-	g_assert_cmpint (array->len, ==, 3);
-
-	data = g_ptr_array_index (array, 0);
-	g_assert_cmpint (data->red, ==, 0);
-	g_assert_cmpint (data->green, ==, 0);
-	g_assert_cmpint (data->blue, ==, 0);
-
-	data = g_ptr_array_index (array, 1);
-	g_assert_cmpint (data->red, ==, 32767);
-	g_assert_cmpint (data->green, ==, 32767);
-	g_assert_cmpint (data->blue, ==, 32767);
-
-	data = g_ptr_array_index (array, 2);
-	g_assert_cmpint (data->red, ==, 65535);
-	g_assert_cmpint (data->green, ==, 65535);
-	g_assert_cmpint (data->blue, ==, 65535);
-
-	g_ptr_array_unref (array);
-
-	/* set some initial properties */
-	g_object_set (clut,
-		      "contrast", 99.0f,
-		      "brightness", 0.0f,
-		      NULL);
-
-	array = gcm_clut_get_array (clut);
-	g_assert_cmpint (array->len, ==, 3);
-
-	data = g_ptr_array_index (array, 0);
-	g_assert_cmpint (data->red, ==, 0);
-	g_assert_cmpint (data->green, ==, 0);
-	g_assert_cmpint (data->blue, ==, 0);
-	data = g_ptr_array_index (array, 1);
-	g_assert_cmpint (data->red, ==, 32439);
-	g_assert_cmpint (data->green, ==, 32439);
-	g_assert_cmpint (data->blue, ==, 32439);
-	data = g_ptr_array_index (array, 2);
-	g_assert_cmpint (data->red, ==, 64879);
-	g_assert_cmpint (data->green, ==, 64879);
-	g_assert_cmpint (data->blue, ==, 64879);
-
-	g_ptr_array_unref (array);
-
-	/* set some initial properties */
-	g_object_set (clut,
-		      "contrast", 100.0f,
-		      "brightness", 1.0f,
-		      NULL);
-
-	array = gcm_clut_get_array (clut);
-	g_assert_cmpint (array->len, ==, 3);
-
-	data = g_ptr_array_index (array, 0);
-	g_assert_cmpint (data->red, ==, 655);
-	g_assert_cmpint (data->green, ==, 655);
-	g_assert_cmpint (data->blue, ==, 655);
-	data = g_ptr_array_index (array, 1);
-	g_assert_cmpint (data->red, ==, 33094);
-	g_assert_cmpint (data->green, ==, 33094);
-	g_assert_cmpint (data->blue, ==, 33094);
-	data = g_ptr_array_index (array, 2);
-	g_assert_cmpint (data->red, ==, 65535);
-	g_assert_cmpint (data->green, ==, 65535);
-	g_assert_cmpint (data->blue, ==, 65535);
-
-	g_ptr_array_unref (array);
-
-	g_object_unref (clut);
+	gcm_color_free_XYZ (white);
+	gcm_color_free_XYZ (red);
+	gcm_color_free_XYZ (green);
+	gcm_color_free_XYZ (blue);
 }
 
 static guint _changes = 0;
@@ -382,6 +352,8 @@ gcm_test_device_func (void)
 	gchar *data;
 	gchar **split;
 	gchar *contents;
+	GcmX11Screen *screen;
+	GcmX11Output *output;
 
 	device = gcm_device_udev_new ();
 	g_assert (device != NULL);
@@ -499,98 +471,38 @@ gcm_test_device_func (void)
 	g_ptr_array_unref (profiles);
 
 	g_object_unref (device);
-}
 
-static void
-gcm_test_dmi_func (void)
-{
-	GcmDmi *dmi;
-
-	dmi = gcm_dmi_new ();
-	g_assert (dmi != NULL);
-	g_assert (gcm_dmi_get_name (dmi) != NULL);
-	g_assert (gcm_dmi_get_version (dmi) != NULL);
-	g_assert (gcm_dmi_get_vendor (dmi) != NULL);
-	g_object_unref (dmi);
-}
-
-typedef struct {
-	const gchar *monitor_name;
-	const gchar *vendor_name;
-	const gchar *serial_number;
-	const gchar *eisa_id;
-	const gchar *checksum;
-	const gchar *pnp_id;
-	guint width;
-	guint height;
-	gfloat gamma;
-} GcmEdidTestData;
-
-static void
-gcm_test_edid_test_parse_edid_file (GcmEdid *edid, const gchar *filename, GcmEdidTestData *test_data)
-{
-	gchar *data;
-	gfloat mygamma;
-	gboolean ret;
-	GError *error = NULL;
-
-	ret = g_file_get_contents (filename, &data, NULL, &error);
+	/* test auto-generation of the profile */
+	device = gcm_device_xrandr_new ();
+	screen = gcm_x11_screen_new ();
+	ret = gcm_x11_screen_assign (screen, NULL, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
+	output = gcm_x11_screen_get_output_by_name (screen, "LVDS1", &error);
+	g_assert_no_error (error);
+	g_assert (output != NULL);
+	g_object_unref (screen);
 
-	ret = gcm_edid_parse (edid, (const guint8 *) data, &error);
+	/* setup device */
+	ret = gcm_device_xrandr_set_from_output (device, output, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
+	g_object_unref (output);
 
-	g_assert_cmpstr (gcm_edid_get_monitor_name (edid), ==, test_data->monitor_name);
-	g_assert_cmpstr (gcm_edid_get_vendor_name (edid), ==, test_data->vendor_name);
-	g_assert_cmpstr (gcm_edid_get_serial_number (edid), ==, test_data->serial_number);
-	g_assert_cmpstr (gcm_edid_get_eisa_id (edid), ==, test_data->eisa_id);
-	g_assert_cmpstr (gcm_edid_get_checksum (edid), ==, test_data->checksum);
-	g_assert_cmpstr (gcm_edid_get_pnp_id (edid), ==, test_data->pnp_id);
-	g_assert_cmpint (gcm_edid_get_height (edid), ==, test_data->height);
-	g_assert_cmpint (gcm_edid_get_width (edid), ==, test_data->width);
-	mygamma = gcm_edid_get_gamma (edid);
-	g_assert_cmpfloat (mygamma, >=, test_data->gamma - 0.01);
-	g_assert_cmpfloat (mygamma, <, test_data->gamma + 0.01);
+	/* generate profile */
+	profile = gcm_device_generate_profile (device, &error);
+	g_assert_no_error (error);
+	g_assert (profile != NULL);
 
-	g_free (data);
-}
+	g_assert_cmpstr (gcm_profile_get_copyright (profile), ==, "No copyright");
 
-static void
-gcm_test_edid_func (void)
-{
-	GcmEdid *edid;
-	GcmEdidTestData test_data;
+	/* DEBUG */
+//	ret = gcm_profile_save (profile, "./moo.icc", &error);
+//	g_assert_no_error (error);
+//	g_assert (ret);
 
-	edid = gcm_edid_new ();
-	g_assert (edid != NULL);
-
-	/* LG 21" LCD panel */
-	test_data.monitor_name = "L225W";
-	test_data.vendor_name = "Goldstar Company Ltd";
-	test_data.serial_number = "34398";
-	test_data.eisa_id = NULL;
-	test_data.checksum = "80b7dda4c74b06366abb8fa23e71d645";
-	test_data.pnp_id = "GSM";
-	test_data.height = 30;
-	test_data.width = 47;
-	test_data.gamma = 2.2f;
-	gcm_test_edid_test_parse_edid_file (edid, TESTDATADIR "/LG-L225W-External.bin", &test_data);
-
-	/* Lenovo T61 Intel Panel */
-	test_data.monitor_name = NULL;
-	test_data.vendor_name = "IBM France";
-	test_data.serial_number = NULL;
-	test_data.eisa_id = "LTN154P2-L05";
-	test_data.checksum = "c585d9e80adc65c54f0a52597e850f83";
-	test_data.pnp_id = "IBM";
-	test_data.height = 21;
-	test_data.width = 33;
-	test_data.gamma = 2.2f;
-	gcm_test_edid_test_parse_edid_file (edid, TESTDATADIR "/Lenovo-T61-Internal.bin", &test_data);
-
-	g_object_unref (edid);
+	g_object_unref (profile);
+	g_object_unref (device);
 }
 
 static void
@@ -685,70 +597,6 @@ gcm_test_gamma_widget_func (void)
 	gtk_widget_destroy (dialog);
 }
 
-static void
-gcm_test_image_func (void)
-{
-	GcmImage *image;
-	GtkWidget *image_test;
-	GtkWidget *dialog;
-	GtkWidget *vbox;
-	gint response;
-	gboolean ret;
-	GcmProfile *profile;
-	GFile *file;
-
-	image = gcm_image_new ();
-	g_assert (image != NULL);
-
-	gtk_image_set_from_file (GTK_IMAGE(image), TESTDATADIR "/image-widget.png");
-
-	/* show in a dialog as an example */
-	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "Does color-corrected image match\nthe picture below?");
-	image_test = gtk_image_new_from_file (TESTDATADIR "/image-widget-good.png");
-	vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-	gtk_box_pack_end (GTK_BOX(vbox), GTK_WIDGET(image), TRUE, TRUE, 12);
-	gtk_box_pack_end (GTK_BOX(vbox), image_test, TRUE, TRUE, 12);
-	gtk_widget_set_size_request (GTK_WIDGET(image), 300, 300);
-	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
-	gtk_widget_show (GTK_WIDGET(image));
-	gtk_widget_show (image_test);
-
-	g_object_set (image,
-		      "use-embedded-profile", TRUE,
-		      "output-profile", NULL,
-		      NULL);
-
-	response = gtk_dialog_run (GTK_DIALOG (dialog));
-	g_assert ((response == GTK_RESPONSE_YES));
-
-	gtk_image_set_from_file (GTK_IMAGE(image_test), TESTDATADIR "/image-widget-nonembed.png");
-	g_object_set (image,
-		      "use-embedded-profile", FALSE,
-		      NULL);
-
-	response = gtk_dialog_run (GTK_DIALOG (dialog));
-	g_assert ((response == GTK_RESPONSE_YES));
-
-	gtk_image_set_from_file (GTK_IMAGE(image_test), TESTDATADIR "/image-widget-output.png");
-	g_object_set (image,
-		      "use-embedded-profile", TRUE,
-		      NULL);
-
-	/* get test file */
-	profile = gcm_profile_new ();
-	file = g_file_new_for_path (TESTDATADIR "/ibm-t61.icc");
-	ret = gcm_profile_parse (profile, file, NULL);
-	g_object_unref (file);
-	g_assert (ret);
-	gcm_image_set_output_profile (image, profile);
-	g_object_unref (profile);
-
-	response = gtk_dialog_run (GTK_DIALOG (dialog));
-	g_assert ((response == GTK_RESPONSE_YES));
-
-	gtk_widget_destroy (dialog);
-}
-
 static GPtrArray *
 gcm_print_test_render_cb (GcmPrint *print,  GtkPageSetup *page_setup, gpointer user_data, GError **error)
 {
@@ -775,134 +623,6 @@ gcm_test_print_func (void)
 	g_object_unref (print);
 }
 
-static void
-gcm_test_profile_func (void)
-{
-	GcmProfile *profile;
-	GFile *file;
-	GcmClut *clut;
-	gboolean ret;
-	GError *error = NULL;
-	GcmXyz *xyz;
-
-	/* bluish test */
-	profile = gcm_profile_new ();
-	file = g_file_new_for_path (TESTDATADIR "/bluish.icc");
-	ret = gcm_profile_parse (profile, file, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-	g_object_unref (file);
-
-	/* get CLUT */
-	clut = gcm_profile_generate_vcgt (profile, 256);
-	g_assert (clut != NULL);
-	g_assert_cmpint (gcm_clut_get_size (clut), ==, 256);
-
-	g_assert_cmpstr (gcm_profile_get_copyright (profile), ==, "Copyright (c) 1998 Hewlett-Packard Company");
-	g_assert_cmpstr (gcm_profile_get_manufacturer (profile), ==, "IEC http://www.iec.ch");
-	g_assert_cmpstr (gcm_profile_get_model (profile), ==, "IEC 61966-2.1 Default RGB colour space - sRGB");
-	g_assert_cmpstr (gcm_profile_get_datetime (profile), ==, "February  9 1998, 06:49:00 AM");
-	g_assert_cmpstr (gcm_profile_get_description (profile), ==, "Blueish Test");
-	g_assert_cmpstr (gcm_profile_get_checksum (profile), ==, "8e2aed5dac6f8b5d8da75610a65b7f27");
-	g_assert_cmpint (gcm_profile_get_kind (profile), ==, GCM_PROFILE_KIND_DISPLAY_DEVICE);
-	g_assert_cmpint (gcm_profile_get_colorspace (profile), ==, GCM_COLORSPACE_RGB);
-	g_assert (gcm_profile_get_has_vcgt (profile));
-
-	/* get extra data */
-	g_object_get (profile,
-		      "red", &xyz,
-		      NULL);
-	g_assert_cmpfloat (fabs (gcm_xyz_get_x (xyz) - 0.648454), <, 0.01);
-
-	g_object_unref (xyz);
-	g_object_unref (clut);
-	g_object_unref (profile);
-
-	/* Adobe test */
-	profile = gcm_profile_new ();
-	file = g_file_new_for_path (TESTDATADIR "/AdobeGammaTest.icm");
-	ret = gcm_profile_parse (profile, file, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-	g_object_unref (file);
-
-	g_assert_cmpstr (gcm_profile_get_copyright (profile), ==, "Copyright (c) 1998 Hewlett-Packard Company Modified using Adobe Gamma");
-	g_assert_cmpstr (gcm_profile_get_manufacturer (profile), ==, "IEC http://www.iec.ch");
-	g_assert_cmpstr (gcm_profile_get_model (profile), ==, "IEC 61966-2.1 Default RGB colour space - sRGB");
-	g_assert_cmpstr (gcm_profile_get_datetime (profile), ==, "August 16 2005, 09:49:54 PM");
-	g_assert_cmpstr (gcm_profile_get_description (profile), ==, "ADOBEGAMMA-Test");
-	g_assert_cmpstr (gcm_profile_get_checksum (profile), ==, "bd847723f676e2b846daaf6759330624");
-	g_assert_cmpint (gcm_profile_get_kind (profile), ==, GCM_PROFILE_KIND_DISPLAY_DEVICE);
-	g_assert_cmpint (gcm_profile_get_colorspace (profile), ==, GCM_COLORSPACE_RGB);
-	g_assert (gcm_profile_get_has_vcgt (profile));
-
-	g_object_unref (profile);
-}
-
-static void
-gcm_test_profile_store_func (void)
-{
-	GcmProfileStore *store;
-	GPtrArray *array;
-	GcmProfile *profile;
-	gboolean ret;
-
-	store = gcm_profile_store_new ();
-	g_assert (store != NULL);
-
-	/* add test files */
-	ret = gcm_profile_store_search_path (store, TESTDATADIR "/.");
-	g_assert (ret);
-
-	/* profile does not exist */
-	profile = gcm_profile_store_get_by_filename (store, "xxxxxxxxx");
-	g_assert (profile == NULL);
-
-	/* profile does exist */
-	profile = gcm_profile_store_get_by_checksum (store, "8e2aed5dac6f8b5d8da75610a65b7f27");
-	g_assert (profile != NULL);
-	g_assert_cmpstr (gcm_profile_get_checksum (profile), ==, "8e2aed5dac6f8b5d8da75610a65b7f27");
-	g_object_unref (profile);
-
-	/* get array of profiles */
-	array = gcm_profile_store_get_array (store);
-	g_assert (array != NULL);
-	g_assert_cmpint (array->len, ==, 3);
-	g_ptr_array_unref (array);
-
-	g_object_unref (store);
-}
-
-static void
-gcm_test_tables_func (void)
-{
-	GcmTables *tables;
-	GError *error = NULL;
-	gchar *vendor;
-
-	tables = gcm_tables_new ();
-	g_assert (tables != NULL);
-
-	vendor = gcm_tables_get_pnp_id (tables, "IBM", &error);
-	g_assert_no_error (error);
-	g_assert (vendor != NULL);
-	g_assert_cmpstr (vendor, ==, "IBM France");
-	g_free (vendor);
-
-	vendor = gcm_tables_get_pnp_id (tables, "MIL", &error);
-	g_assert_no_error (error);
-	g_assert (vendor != NULL);
-	g_assert_cmpstr (vendor, ==, "Marconi Instruments Ltd");
-	g_free (vendor);
-
-	vendor = gcm_tables_get_pnp_id (tables, "XXX", &error);
-	g_assert_error (error, 1, 0);
-	g_assert_cmpstr (vendor, ==, NULL);
-	g_free (vendor);
-
-	g_object_unref (tables);
-}
-
 static void
 gcm_test_trc_widget_func (void)
 {
@@ -998,11 +718,6 @@ gcm_test_utils_func (void)
 	g_assert_cmpstr (filename, ==, "Hel lo__Wo-(r)ld_");
 	g_free (filename);
 
-	text = g_strdup ("1\r34 67_90");
-	gcm_utils_ensure_printable (text);
-	g_assert_cmpstr (text, ==, "134 67 90");
-	g_free (text);
-
 	/* get default config location (when in make check) */
 	g_setenv ("GCM_TEST", "1", TRUE);
 	filename = gcm_utils_get_default_config_location ();
@@ -1013,38 +728,6 @@ gcm_test_utils_func (void)
 	g_assert (gcm_utils_device_kind_to_profile_kind (GCM_DEVICE_KIND_UNKNOWN) == GCM_PROFILE_KIND_UNKNOWN);
 }
 
-static void
-gcm_test_xyz_func (void)
-{
-	GcmXyz *xyz;
-	gdouble value;
-
-	xyz = gcm_xyz_new ();
-	g_assert (xyz != NULL);
-
-	/* nothing set */
-	value = gcm_xyz_get_x (xyz);
-	g_assert_cmpfloat (fabs (value - 0.0f), <, 0.001f);
-
-	/* set dummy values */
-	g_object_set (xyz,
-		      "cie-x", 0.125,
-		      "cie-y", 0.25,
-		      "cie-z", 0.5,
-		      NULL);
-
-	value = gcm_xyz_get_x (xyz);
-	g_assert_cmpfloat (fabs (value - 0.142857143f), <, 0.001f);
-
-	value = gcm_xyz_get_y (xyz);
-	g_assert_cmpfloat (fabs (value - 0.285714286f), <, 0.001f);
-
-	value = gcm_xyz_get_z (xyz);
-	g_assert_cmpfloat (fabs (value - 0.571428571f), <, 0.001f);
-
-	g_object_unref (xyz);
-}
-
 static void
 gcm_test_client_func (void)
 {
@@ -1154,25 +837,20 @@ main (int argc, char **argv)
 	gtk_init (&argc, &argv);
 	g_test_init (&argc, &argv, NULL);
 
+	/* setup manually as we have no GMainContext */
+	gcm_debug_setup (g_getenv ("VERBOSE") != NULL);
+
 	g_test_add_func ("/color/client", gcm_test_client_func);
-	g_test_add_func ("/color/dmi", gcm_test_dmi_func);
 	g_test_add_func ("/color/calibrate", gcm_test_calibrate_func);
-	g_test_add_func ("/color/edid", gcm_test_edid_func);
 	g_test_add_func ("/color/exif", gcm_test_exif_func);
-	g_test_add_func ("/color/tables", gcm_test_tables_func);
 	g_test_add_func ("/color/utils", gcm_test_utils_func);
 	g_test_add_func ("/color/device", gcm_test_device_func);
-	g_test_add_func ("/color/profile", gcm_test_profile_func);
-	g_test_add_func ("/color/profile_store", gcm_test_profile_store_func);
-	g_test_add_func ("/color/clut", gcm_test_clut_func);
-	g_test_add_func ("/color/xyz", gcm_test_xyz_func);
 	g_test_add_func ("/color/calibrate_dialog", gcm_test_calibrate_dialog_func);
 	if (g_test_thorough ()) {
-		g_test_add_func ("/color/brightness", gcm_test_brightness_func);
+		g_test_add_func ("/color/calibrate_native", gcm_test_calibrate_native_func);
 		g_test_add_func ("/color/trc", gcm_test_trc_widget_func);
 		g_test_add_func ("/color/cie", gcm_test_cie_widget_func);
 		g_test_add_func ("/color/gamma_widget", gcm_test_gamma_widget_func);
-		g_test_add_func ("/color/image", gcm_test_image_func);
 	}
 	if (g_test_slow ()) {
 		g_test_add_func ("/color/print", gcm_test_print_func);
